@@ -17,7 +17,7 @@
  *
  * @copyright &copy; 2000-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: config_default.php,v 1.84.2.16 2006/06/08 15:37:31 kink Exp $
+ * @version $Id: config_default.php,v 1.84.2.19 2006/08/01 05:47:32 tokul Exp $
  * @package squirrelmail
  * @subpackage config
  */
@@ -178,6 +178,20 @@ $encode_header_key = '';
  * @global string $sendmail_path
  */
 $sendmail_path = '/usr/sbin/sendmail';
+
+/**
+ * Extra sendmail command arguments.
+ *
+ * Sets additional sendmail command arguments. Make sure that arguments are
+ * supported by your sendmail program. -f argument is added automatically by
+ * SquirrelMail scripts. Variable defaults to standard /usr/sbin/sendmail
+ * arguments. If you use qmail-inject, nbsmtp or any other sendmail wrapper,
+ * which does not support -t and -i arguments, set variable to empty string
+ * or use arguments suitable for your mailer.
+ * @global string $sendmail_args
+ * @since 1.5.1 and 1.4.8
+ */
+$sendmail_args = '-i -t';
     
 /**
  * IMAP server address
@@ -600,6 +614,31 @@ $uid_support              = true;
 $session_name = 'SQMSESSID';
 
 
+/**
+ * Location base
+ * 
+ * This is used to build the URL to the SquirrelMail location.
+ * It should contain only the protocol and hostname/port parts
+ * of the URL; the full path will be appended automatically.
+ *
+ * If not specified or empty, it will be autodetected.
+ *
+ * Examples:
+ * http://webmail.example.org
+ * http://webmail.example.com:8080
+ * https://webmail.example.com:6691
+ *
+ * To be clear: do not include any of the path elements, so if
+ * SquirrelMail is at http://www.example.net/web/mail/src/login.php, you
+ * write: http://www.example.net
+ *
+ * @global string $config_location_base
+ * @since 1.4.8
+ */
+$config_location_base = '';
+
+
+
 /**
  * Themes
  *   You can define your own theme and put it in this directory.
