@@ -3,13 +3,12 @@
 /**
  * display_messages.php
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This contains all messages, including information, error, and just
  * about any other message you can think of.
  *
- * @version $Id: display_messages.php,v 1.57.2.20 2006/02/03 22:27:47 jervfors Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: display_messages.php,v 1.57.2.22 2006/05/14 17:45:29 tokul Exp $
  * @package squirrelmail
  */
 
@@ -24,7 +23,7 @@ function error_message($message, $mailbox, $sort, $startMessage, $color) {
               '<tr><td align="center">'.
               '<a href="'.sqm_baseuri()."src/right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox\">".
               sprintf (_("Click here to return to %s"),
-                  imap_utf7_decode_local($mailbox)).
+                  htmlspecialchars(imap_utf7_decode_local($mailbox))).
               '</a></td></tr>';
     error_box($string, $color);
 }
