@@ -3,12 +3,11 @@
 /**
  * imap_mailbox.php
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
+ * This implements all functions that manipulate mailboxes
  *
- * This impliments all functions that manipulate mailboxes
- *
- * @version $Id: imap_mailbox.php,v 1.172.2.24 2006/02/03 22:27:47 jervfors Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: imap_mailbox.php,v 1.172.2.26 2006/05/21 12:26:31 tokul Exp $
  * @package squirrelmail
  * @subpackage imap
  */
@@ -226,10 +225,12 @@ function sqimap_mailbox_select ($imap_stream, $mailbox) {
 function sqimap_mailbox_create ($imap_stream, $mailbox, $type) {
     global $delimiter;
     if (strtolower($type) == 'noselect') {
-        $mailbox .= $delimiter;
+        $create_mailbox = $mailbox . $delimiter;
+    } else {
+        $create_mailbox = $mailbox;
     }
 
-    $read_ary = sqimap_run_command($imap_stream, "CREATE \"$mailbox\"",
+    $read_ary = sqimap_run_command($imap_stream, "CREATE \"$create_mailbox\"",
                                    true, $response, $message);
     sqimap_subscribe ($imap_stream, $mailbox);
 }
