@@ -3,12 +3,12 @@
 /**
  * imap_search.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
+ * Copyright (c) 1999-2006 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * IMAP search routines
  *
- * @version $Id: imap_search.php,v 1.63.2.4 2004/12/27 15:03:45 kink Exp $
+ * @version $Id: imap_search.php,v 1.63.2.7 2006/02/03 22:27:47 jervfors Exp $
  * @package squirrelmail
  * @subpackage imap
  * @deprecated This search interface has been largely replaced by asearch
@@ -85,7 +85,7 @@ function sqimap_search($imapConnection, $search_where, $search_what, $mailbox,
         && strtolower($result) == 'no') {
         $ss = "SEARCH CHARSET \"US-ASCII\" ALL $search_string";
         $readin = sqimap_run_command ($imapConnection, $ss, true,
-                                      $result, $message);
+                                      $result, $message, $uid_support);
     }
 
     unset($messagelist);
@@ -126,4 +126,4 @@ function sqimap_search($imapConnection, $search_where, $search_what, $mailbox,
 
 
 
-?>
+?>
\ No newline at end of file
