@@ -3,13 +3,12 @@
 /**
  * mailbox_display.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * @version $Id: mailbox_display.php,v 1.321.2.25 2004/12/29 19:12:05 jervfors Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: mailbox_display.php,v 1.321.2.35 2006/06/08 14:59:19 kink Exp $
  * @package squirrelmail
  */
 
@@ -52,7 +51,10 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
            $thread_sort_messages, /* thread sorting on/off */
            $server_sort_order, /* sort value when using server-sorting */
            $row_count,
-           $allow_server_sort; /* enable/disable server-side sorting */
+           $allow_server_sort, /* enable/disable server-side sorting */
+           $truncate_subject,
+           $truncate_sender;
+
     $color_string = $color[4];
 
     if ($GLOBALS['alt_index_colors']) {
@@ -81,6 +83,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     }
     $msg['FROM'] = parseAddress($msg['FROM'],1);
 
+
        /*
         * This is done in case you're looking into Sent folders,
         * because you can have multiple receivers.
@@ -88,20 +91,30 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
 
     $senderNames = $msg['FROM'];
     $senderName  = '';
+    $senderFrom = '';
+
+
     if (sizeof($senderNames)){
         foreach ($senderNames as $senderNames_part) {
             if ($senderName != '') {
                 $senderName .= ', ';
             }
+
+            if ($senderFrom != '') {
+                $senderFrom .= ', ';
+            }
+
             if ($senderNames_part[1]) {
                 $senderName .= decodeHeader($senderNames_part[1]);
             } else {
                 $senderName .= htmlspecialchars($senderNames_part[0]);
             }
+
+            $senderFrom .= htmlspecialchars($senderNames_part[0]);
         }
     }
     $senderName = str_replace('&nbsp;',' ',$senderName);
-    echo html_tag( 'tr','','','','VALIGN="top"') . "\n";
+    echo html_tag( 'tr','','','','valign="top"') . "\n";
 
     if (isset($msg['FLAG_FLAGGED']) && ($msg['FLAG_FLAGGED'] == true)) {
         $flag = "<font color=\"$color[2]\">";
@@ -184,8 +197,8 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     $checked = ($checkall == 1) ? ' CHECKED' : '';
     $col = 0;
     $msg['SUBJECT'] = decodeHeader($msg['SUBJECT']);
-    $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
-    $subject = str_replace('&nbsp;',' ',$subject);
+//    $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
+    $subject = truncateWithEntities(str_replace('&nbsp;',' ',$msg['SUBJECT']), $truncate_subject);
     if (sizeof($index_order)) {
         foreach ($index_order as $index_order_part) {
             switch ($index_order_part) {
@@ -196,11 +209,13 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                                $hlt_color );
                 break;
             case 2: /* from */
+                $from_xtra = '';
+                $from_xtra = 'title="' . $senderFrom . '"';
                 echo html_tag( 'td',
-                               $italic . $bold . $flag . $fontstr . $senderName .
+                               $italic . $bold . $flag . $fontstr . truncateWithEntities($senderName, $truncate_sender) .
                                $fontstr_end . $flag_end . $bold_end . $italic_end,
                                'left',
-                               $hlt_color );
+                               $hlt_color, $from_xtra );
                 break;
             case 3: /* date */
                 $date_string = $msg['DATE_STRING'] . '';
@@ -284,8 +299,8 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
         }
     }
     if ($not_last) {
-        echo '</tr>' . "\n" . '<tr><td COLSPAN="' . $col . '" BGCOLOR="' .
-             $color[0] . '" HEIGHT="1"></td></tr>' . "\n";
+        echo '</tr>' . "\n" . '<tr><td colspan="' . $col . '" bgcolor="' .
+             $color[0] . '" height="1"></td></tr>' . "\n";
     } else {
         echo '</tr>'."\n";
     }
@@ -478,8 +493,12 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     $start_msg = $res[0];
     $end_msg   = $res[1];
 
-    $paginator_str = get_paginator_str($mailbox, $start_msg, $end_msg,
-                                       $num_msgs, $show_num, $sort);
+    if ($num_msgs > 0) {
+        $paginator_str = get_paginator_str($mailbox, $start_msg, $end_msg,
+                                           $num_msgs, $show_num, $sort);
+    } else {
+        $paginator_str = '';
+    }
 
     $msg_cnt_str = get_msgcnt_str($start_msg, $end_msg, $num_msgs);
 
@@ -491,7 +510,7 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
                                   $msg_cnt_str, $paginator_str, $start_msg);
     echo '</td></tr>';
     /* line between the button area and the list */
-    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';
+    echo '<tr><td height="5" bgcolor="'.$color[4].'"></td></tr>';
 
     echo '<tr><td>';
     echo '    <table width="100%" cellpadding="1" cellspacing="0" align="center"'.' border="0" bgcolor="'.$color[9].'">';
@@ -594,10 +613,10 @@ function displayMessageArray($imapConnection, $num_msgs, $start_msg,
     /* if there's no messages in this folder */
         echo html_tag( 'tr',
                 html_tag( 'td',
-                          "<BR><b>" . _("THIS FOLDER IS EMPTY") . "</b><BR>&nbsp;",
+                          "<br><b>" . _("THIS FOLDER IS EMPTY") . "</b><br>&nbsp;",
                           'center',
                           $color[4],
-                          'COLSPAN="' . count($index_order) . '"'
+                          'colspan="' . count($index_order) . '"'
                 )
         );
     } elseif ($start_msg == $end_msg) {
@@ -674,12 +693,10 @@ function mail_message_listing_beginning ($imapConnection,
     if (!isset($msg)) {
         $msg = '';
     }
-    $moveFields = '<input type="hidden" name="msg" value="'.htmlspecialchars($msg).'">' .
-		  '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' .
-		  '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">';
+    $moveFields = '<input type="hidden" name="msg" value="'.htmlspecialchars($msg).'">' . "\n" .
+		  '<input type="hidden" name="mailbox" value="'.htmlspecialchars($mailbox).'">' . "\n" .
+		  '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">' . "\n";
 
-//    $moveURL = "move_messages.php?msg=$msg&amp;mailbox=$urlMailbox"
-//             . "&amp;startMessage=$start_msg";
     /*
      * This is the beginning of the message list table.
      * It wraps around all messages
@@ -687,8 +704,11 @@ function mail_message_listing_beginning ($imapConnection,
     $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
     $form_name = "FormMsgs" . $safe_name;
     echo '<form name="' . $form_name . '" method="post" action="move_messages.php">' ."\n"
-	. $moveFields
-        . html_tag( 'table' ,
+        . $moveFields . "\n";
+
+    if (!empty($paginator) && !empty($msg_cnt_str)) {
+
+        echo html_tag( 'table' ,
             html_tag( 'tr',
                 html_tag( 'td' ,
                     html_tag( 'table' ,
@@ -700,8 +720,9 @@ function mail_message_listing_beginning ($imapConnection,
                 , 'left', '', '' )
             , '', $color[0] )
 	    , '', '', 'border="0" width="100%" cellpadding="1"  cellspacing="0"' );
+    }
 	/* line between header and button area */
-        echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';
+        echo '</td></tr><tr><td height="5" bgcolor="'.$color[4].'"></td></tr>';
 
         echo '<tr><td>';
         echo html_tag( 'tr' ) . "\n"
@@ -726,7 +747,7 @@ function mail_message_listing_beginning ($imapConnection,
 
     if (!$auto_expunge) {
         echo getButton('SUBMIT', 'expungeButton',_("Expunge"))
-             .'&nbsp;' . _("mailbox") . "\n";
+             ."&nbsp;\n";
     }
 
     echo getButton('SUBMIT', 'markRead',_("Read"));
@@ -740,9 +761,9 @@ function mail_message_listing_beginning ($imapConnection,
 
 //    $location = urlencode($location);
 
-    echo '<INPUT TYPE="HIDDEN" NAME="location" VALUE="'.$location.'">';
-    echo "</TD>\n"
-         . "   </TR>\n";
+    echo '<input type="hidden" name="location" value="'.$location.'">';
+    echo "</td>\n"
+         . "   </tr>\n";
 
     /* draws thread sorting links */
     if ($allow_thread_sort == TRUE) {
@@ -763,7 +784,7 @@ function mail_message_listing_beginning ($imapConnection,
                  , '', '', '' );
     }
 
-    echo "</TABLE></td></tr></table></td></tr>\n";
+    echo "</table></td></tr></table></td></tr>\n";
 
     do_hook('mailbox_form_before');
 
@@ -780,7 +801,7 @@ function mail_message_listing_beginning ($imapConnection,
 function mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color) {
   if ($num_msgs) {
     /* space between list and footer */
-    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'" COLSPAN="1">';
+    echo '<tr><td height="5" bgcolor="'.$color[4].'" colspan="1">';
 
     echo '</td></tr><tr><td>';
     echo html_tag( 'table',
@@ -800,7 +821,7 @@ function mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $colo
     /* End of message-list table */
 
     do_hook('mailbox_index_after');
-    echo "</FORM>\n";
+    echo "</form>\n";
 }
 
 function printHeader($mailbox, $sort, $color, $showsort=true) {
@@ -885,8 +906,8 @@ function ShowSortButton($sort, $mailbox, $Up, $Down ) {
     /* Now that we have everything figured out, show the actual button. */
     echo ' <a href="' . $source_url .'?newsort=' . $which
          . '&amp;startMessage=1&amp;mailbox=' . urlencode($mailbox)
-         . '"><IMG SRC="../images/' . $img
-         . '" BORDER=0 WIDTH=12 HEIGHT=10 ALT="sort"></a>';
+         . '"><img src="../images/' . $img
+         . '" border="0" width="12" height="10" alt="sort"></a>';
 }
 
 function get_selectall_link($start_msg, $sort) {
@@ -968,9 +989,9 @@ function get_msgcnt_str($start_msg, $end_msg, $num_msgs) {
 function get_paginator_link($box, $start_msg, $use, $text) {
     global $PHP_SELF;
 
-    $result = "<A HREF=\"right_main.php?use_mailbox_cache=$use"
+    $result = "<a href=\"right_main.php?use_mailbox_cache=$use"
             . "&amp;startMessage=$start_msg&amp;mailbox=$box\" "
-            . ">$text</A>";
+            . ">$text</a>";
     return ($result);
 /*
     if (preg_match('/^(.+)\?.+$/',$PHP_SELF,$regs)) {
@@ -1031,9 +1052,9 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
         $nxt_str = get_paginator_link($box, $next_grp, $use, _("Next"));
     } else if (($next_grp > $num_msgs) && ($prev_grp >= 0)) {
         $prv_str = get_paginator_link($box, $prev_grp, $use, _("Previous"));
-        $nxt_str = "<FONT COLOR=\"$color[9]\">"._("Next")."</FONT>\n";
+        $nxt_str = "<font color=\"$color[9]\">"._("Next")."</font>\n";
     } else if (($next_grp <= $num_msgs) && ($prev_grp < 0)) {
-        $prv_str = "<FONT COLOR=\"$color[9]\">"._("Previous") . '</FONT>';
+        $prv_str = "<font color=\"$color[9]\">"._("Previous") . '</font>';
         $nxt_str = get_paginator_link($box, $next_grp, $use, _("Next"));
     }
 
@@ -1152,16 +1173,16 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
             }
         }
     } else if ($PG_SHOWNUM == 999999) {
-        $pg_str = "<A HREF=\"right_main.php?PG_SHOWALL=0"
+        $pg_str = "<a href=\"right_main.php?PG_SHOWALL=0"
                 . "&amp;use_mailbox_cache=$use&amp;startMessage=1&amp;mailbox=$box\" "
-                . ">" ._("Paginate") . '</A>' . $spc;
+                . ">" ._("Paginate") . '</a>' . $spc;
     }
 
     /* If necessary, compute the 'show all' string. */
     if (($prv_str != '') || ($nxt_str != '')) {
-        $all_str = "<A HREF=\"right_main.php?PG_SHOWALL=1"
+        $all_str = "<a href=\"right_main.php?PG_SHOWALL=1"
                  . "&amp;use_mailbox_cache=$use&amp;startMessage=1&amp;mailbox=$box\" "
-                 . ">" . _("Show All") . '</A>';
+                 . ">" . _("Show All") . '</a>';
     }
 
     /* Last but not least, get the value for the toggle all link. */
@@ -1250,11 +1271,11 @@ function getMbxList($imapConnection) {
     global $lastTargetMailbox;
     echo  '         <small>&nbsp;<tt><select name="targetMailbox">';
     echo sqimap_mailbox_option_list($imapConnection, array(strtolower($lastTargetMailbox)) );
-    echo '         </SELECT></TT>&nbsp;';
+    echo '         </select></tt>&nbsp;';
 }
 
 function getButton($type, $name, $value) {
-    return '<INPUT TYPE="'.$type.'" NAME="'.$name.'" VALUE="'.$value . '">';
+    return '<input type="'.$type.'" name="'.$name.'" value="'.$value . '">';
 }
 
 function getSmallStringCell($string, $align) {
@@ -1295,4 +1316,4 @@ function handleAsSent($mailbox) {
 }
 
 // vim: et ts=4
-?>
\ No newline at end of file
+?>
