@@ -3,13 +3,12 @@
 /**
  * mime.php
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This contains the functions necessary to detect and decode MIME
  * messages.
  *
- * @version $Id: mime.php,v 1.265.2.65 2006/02/23 14:13:47 kink Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: mime.php,v 1.265.2.68 2006/06/20 06:14:53 jervfors Exp $
  * @package squirrelmail
  */
 
@@ -303,9 +302,10 @@ function formatBody($imap_stream, $message, $color, $wrap_at, $ent_num, $id, $ma
      * primary message. To add more of them, just put them in the
      * order that is their priority.
      */
-    global $startMessage, $username, $key, $imapServerAddress, $imapPort,
-           $show_html_default, $sort, $has_unsafe_images, $passed_ent_id;
-    global $languages, $squirrelmail_language;
+    global $startMessage, $languages, $squirrelmail_language,
+           $show_html_default, $sort, $has_unsafe_images, $passed_ent_id,
+           $username, $key, $imapServerAddress, $imapPort,
+           $download_and_unsafe_link;
 
     if( !sqgetGlobalVar('view_unsafe_images', $view_unsafe_images, SQ_GET) ) {
         $view_unsafe_images = false;
@@ -362,13 +362,15 @@ function formatBody($imap_stream, $message, $color, $wrap_at, $ent_num, $id, $ma
             return $body;
         }
 
+        $download_and_unsafe_link = '';
+
         $link = 'passed_id=' . $id . '&amp;ent_id='.$ent_num.
             '&amp;mailbox=' . $urlmailbox .'&amp;sort=' . $sort .
             '&amp;startMessage=' . $startMessage . '&amp;show_more=0';
         if (isset($passed_ent_id)) {
             $link .= '&amp;passed_ent_id='.$passed_ent_id;
         }
-        $body .= '<center><small><a href="download.php?absolute_dl=true&amp;' .
+        $download_and_unsafe_link .= '&nbsp;|&nbsp;<a href="download.php?absolute_dl=true&amp;' .
             $link . '">' . _("Download this as a file") .  '</a>';
         if ($view_unsafe_images) {
             $text = _("Hide Unsafe Images");
@@ -381,9 +383,8 @@ function formatBody($imap_stream, $message, $color, $wrap_at, $ent_num, $id, $ma
             }
         }
         if($text != '') {
-            $body .= '&nbsp;|&nbsp;<a href="read_body.php?' . $link . '">' . $text . '</a>';
+            $download_and_unsafe_link .= '&nbsp;|&nbsp;<a href="read_body.php?' . $link . '">' . $text . '</a>';
         }
-        $body .= '</small></center><br />' . "\n";
     }
     return $body;
 }
@@ -646,8 +647,8 @@ function decodeHeader ($string, $utfencode=true,$htmlsave=true,$decide=false) {
                 case 'B':
                     $replace = base64_decode($res[4]);
                     if ($can_be_encoded) {
-                        // string is converted from one charset to another and sanitized
-                        $replace =  charset_convert($res[2],$replace,$default_charset);
+                        // string is converted from one charset to another. sanitizing depends on $htmlsave
+                        $replace =  charset_convert($res[2],$replace,$default_charset,$htmlsave);
                     } elseif ($utfencode) {
                         // string is converted to htmlentities and sanitized
                         $replace = charset_decode($res[2],$replace);
@@ -662,8 +663,8 @@ function decodeHeader ($string, $utfencode=true,$htmlsave=true,$decide=false) {
                     $replace = preg_replace('/=([0-9a-f]{2})/ie', 'chr(hexdec("\1"))',
                             $replace);
                     if ($can_be_encoded) {
-                        // string is converted from one charset to another and sanitized
-                        $replace = charset_convert($res[2], $replace,$default_charset);
+                        // string is converted from one charset to another. sanitizing depends on $htmlsave
+                        $replace = charset_convert($res[2], $replace,$default_charset,$htmlsave);
                     } elseif ($utfencode) {
                         // string is converted to html entities and sanitized
                         $replace = charset_decode($res[2], $replace);
@@ -2208,4 +2209,4 @@ function SendDownloadHeaders($type0, $type1, $filename, $force, $filesize=0) {
 
 }  // end fn SendDownloadHeaders
 
-?>
+?>
\ No newline at end of file
