@@ -8,7 +8,7 @@
  *
  * @copyright &copy; 1999-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: strings.php,v 1.184.2.53 2006/07/04 18:48:56 jangliss Exp $
+ * @version $Id: strings.php,v 1.184.2.57 2006/08/11 11:15:43 kink Exp $
  * @package squirrelmail
  */
 
@@ -16,14 +16,14 @@
  * SquirrelMail version number -- DO NOT CHANGE
  */
 global $version;
-$version = '1.4.7';
+$version = '1.4.8';
 
 /**
  * SquirrelMail internal version number -- DO NOT CHANGE
  * $sm_internal_version = array (release, major, minor)
  */
 global $SQM_INTERNAL_VERSION;
-$SQM_INTERNAL_VERSION = array(1,4,7);
+$SQM_INTERNAL_VERSION = array(1,4,8);
 
 /**
  * There can be a circular issue with includes, where the $version string is
@@ -258,17 +258,15 @@ function sqm_baseuri(){
  *
  * Determines the location to forward to, relative to your server.
  * This is used in HTTP Location: redirects.
- * If this doesnt work correctly for you (although it should), you can
- * remove all this code except the last two lines, and have it return
- * the right URL for your site, something like:
- *
- *   http://www.example.com/squirrelmail/
+ * If set, it uses $config_location_base as the first part of the URL,
+ * specifically, the protocol, hostname and port parts. The path is
+ * always autodetected.
  *
  * @return string the base url for this SquirrelMail installation
  */
 function get_location () {
 
-    global $imap_server_type;
+    global $imap_server_type, $config_location_base;
 
     /* Get the path, handle virtual directories */
     if(strpos(php_self(), '?')) {
@@ -277,9 +275,18 @@ function get_location () {
         $path = php_self();
     }
     $path = substr($path, 0, strrpos($path, '/'));
-    if ( sqgetGlobalVar('sq_base_url', $full_url, SQ_SESSION) ) {
-      return $full_url . $path;
+
+    // proto+host+port are already set in config:
+    if ( !empty($config_location_base) ) {
+        // register it in the session just in case some plugin depends on this
+        sqsession_register($config_location_base . $path, 'sq_base_url');
+        return $config_location_base . $path ;
     }
+    // we computed it before, get it from the session:
+    if ( sqgetGlobalVar('sq_base_url', $full_url, SQ_SESSION) ) {
+        return $full_url . $path;
+    }
+    // else: autodetect
 
     /* Check if this is a HTTPS or regular HTTP request. */
     $proto = 'http://';
@@ -566,7 +573,9 @@ function quoteimap($str) {
  * Trims array
  *
  * Trims every element in the array, ie. remove the first char of each element
+ * Obsolete: will probably removed soon
  * @param array array the array to trim
+ * @obsolete
  */
 function TrimArray(&$array) {
     foreach ($array as $k => $v) {
