@@ -1,18 +1,29 @@
 <?php
-
 /**
- * setup.php
+ * Administrator plugin - Setup script
  *
- * Copyright (c) 1999-2002 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
+ * Plugin allows remote administration.
  *
- *  Administrator plugin. Allows remote administration.  Philippe Mingo
- *
- * $Id: setup.php,v 1.5 2002/01/31 10:46:16 philippe_mingo Exp $
+ * @version $Id: setup.php,v 1.7.2.5 2006/02/03 22:27:51 jervfors Exp $
+ * @author Philippe Mingo
+ * @copyright (c) 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @package plugins
+ * @subpackage administrator
  */
 
-require_once('../plugins/administrator/auth.php');
+/** add SM_PATH */
+if (!defined('SM_PATH'))  {
+    define('SM_PATH','../../');
+}
 
+/** @ignore */
+require_once(SM_PATH . 'plugins/administrator/auth.php');
+
+/**
+ * Init the plugin
+ * @access private
+ */
 function squirrelmail_plugin_init_administrator() {
     global $squirrelmail_plugin_hooks, $username;
 
@@ -22,6 +33,10 @@ function squirrelmail_plugin_init_administrator() {
     }
 }
 
+/**
+ * Register option block
+ * @access private
+ */
 function squirrelmail_administrator_optpage_register_block() {
     global $optpage_blocks;
     global $AllowSpamFilters;
