@@ -11,7 +11,7 @@
  * this plugin displays a menu which gives the user a choice of mailinglist
  * commands such as (un)subscribe, help and list archives.
  *
- * $Id: setup.php,v 1.24.2.9 2006/02/03 22:27:52 jervfors Exp $
+ * $Id: setup.php,v 1.24.2.10 2006/03/12 13:53:14 kink Exp $
  * @package plugins
  * @subpackage listcommands
  */
@@ -63,7 +63,7 @@ function plugin_listcommands_menu() {
             } else {
                 $url = "plugins/listcommands/mailout.php?action=$cmd&amp;";
             }
-            $url .= 'send_to=' . strtr($act,'?','&');
+            $url .= 'send_to=' . str_replace('?','&amp;', $act);
 
             $output[] = makeComposeLink($url, $fieldsdescr[$cmd]);
 
@@ -91,4 +91,4 @@ function plugin_listcommands_menu() {
     }
 }
 
-?>
\ No newline at end of file
+?>
