@@ -3,17 +3,17 @@
 /**
  * addrbook_search.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Handle addressbook searching in the popup window.
  *
  * NOTE: A lot of this code is similar to the code in
  *       addrbook_search_html.html -- If you change one,
  *       change the other one too!
  *
- * @version $Id: addrbook_search.php,v 1.49.2.7 2004/12/27 15:03:59 kink Exp $ 
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: addrbook_search.php,v 1.49.2.12 2006/04/14 22:27:08 jervfors Exp $
  * @package squirrelmail
+ * @subpackage addressbook
  */
 
 /**
@@ -131,7 +131,7 @@ function display_result($res, $includesource = true) {
     html_tag( 'th', '&nbsp;' . _("Info"), 'left' );
 
     if ($includesource) {
-        echo html_tag( 'th', '&nbsp;' . _("Source"), 'left', 'width="10%"' );
+        echo html_tag( 'th', '&nbsp;' . _("Source"), 'left', '', 'width="10%"' );
     }    
     echo "</tr>\n";
     
@@ -215,8 +215,9 @@ if ($show == 'form' && empty($listall)) {
 
     /* List all backends to allow the user to choose where to search */
     if ($abook->numbackends > 1) {
-        echo '<strong>' . _("in") . '</strong>&nbsp;'."\n".
-             $selopts['-1'] = _("All address books");
+        echo '<strong>' . _("in") . '</strong>&nbsp;'."\n";
+        $selopts = array();
+        $selopts['-1'] = _("All address books");
 
         $ret = $abook->get_backend_list();
         while (list($undef,$v) = each($ret)) {
@@ -302,4 +303,4 @@ if ($show == 'form' && empty($listall)) {
    
 }
 ?>
-</body></html>
+</body></html>
\ No newline at end of file
