@@ -5,7 +5,7 @@
  *
  * @copyright &copy; 2003-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: configtest.php,v 1.9.2.18 2006/04/14 22:27:08 jervfors Exp $
+ * @version $Id: configtest.php,v 1.9.2.21 2006/07/25 09:16:25 kink Exp $
  * @package squirrelmail
  * @subpackage config
  */
@@ -40,6 +40,10 @@ if (file_exists(SM_PATH . 'config/config.php')) {
     include(SM_PATH . 'config/config.php');
     include(SM_PATH . 'functions/strings.php');
 }
+
+// this must be done before the output is started because it may use the
+// session
+$test_location = get_location();
 ?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
 <html>
 <head>
@@ -110,12 +114,13 @@ if (function_exists('mb_internal_encoding') &&
  * php.ini, webserver config and .htaccess files. Scripts can turn off globals only
  * in php 4.2.3 or older.
  */
-if ((bool) ini_get('register_globals')) {
-    $rg_error='You have enabled php register_globals.'
+if ((bool) ini_get('register_globals') && 
+    ini_get('register_globals') != 'off') {
+    $rg_error='You have enabled PHP register_globals.'
         .' Running PHP installation with register_globals=on can cause problems.'
         .' See <a href="http://www.php.net/manual/en/security.registerglobals.php">'
         .'security information about register_globals</a>.';
-    do_err($rg_error);
+    do_err($rg_error,false);
 }
 
 /* checking paths */
@@ -194,8 +199,10 @@ if ( $squirrelmail_default_language != 'en_US' ) {
     echo $IND . "Default language OK.<br />\n";
 }
 
-echo $IND . "Base URL detected as: <tt>" . htmlspecialchars(get_location()) . "</tt><br />\n";
 
+echo $IND . "Base URL detected as: <tt>" . htmlspecialchars($test_location) .
+    "</tt> (location base " . (empty($config_location_base) ? 'autodetected' : 'set to <tt>' .
+    htmlspecialchars($config_location_base)."</tt>") . ")<br />\n";
 
 /* check outgoing mail */
 
@@ -412,4 +419,4 @@ if(!empty($addrbook_dsn) || !empty($prefs_dsn) || !empty($addrbook_global_dsn))
 </html>
 <?php
 // vim: et ts=4
-?>
\ No newline at end of file
+?>
