@@ -8,7 +8,7 @@
  *
  * @copyright &copy; 1999-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: login.php,v 1.98.2.13 2006/06/02 15:51:45 tokul Exp $
+ * @version $Id: login.php,v 1.98.2.14 2006/08/03 14:48:09 kink Exp $
  * @package squirrelmail
  */
 
@@ -43,13 +43,24 @@ if (!function_exists('sqm_baseuri')){
 }
 $base_uri = sqm_baseuri();
 
-/*
+/**
  * In case the last session was not terminated properly, make sure
- * we get a new one.
+ * we get a new one, but make sure we preserve session_expired_*
  */
 
-sqsession_destroy();
- 
+if ( !empty($_SESSION['session_expired_post']) && !empty($_SESSION['session_expired_location']) ) {
+    $sep = $_SESSION['session_expired_post'];
+    $sel = $_SESSION['session_expired_location'];
+
+    sqsession_destroy();
+
+    sqsession_is_active();
+    sqsession_register($sep, 'session_expired_post');
+    sqsession_register($sel, 'session_expired_location');
+} else {
+    sqsession_destroy();
+}
+
 header('Pragma: no-cache');
 
 do_hook('login_cookie');
@@ -179,4 +190,4 @@ echo '</form>' . "\n";
 
 do_hook('login_bottom');
 ?>
-</body></html>
\ No newline at end of file
+</body></html>
