@@ -7,7 +7,7 @@
  *
  * @copyright &copy; 1999-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: redirect.php,v 1.72.2.11 2006/04/14 22:27:08 jervfors Exp $
+ * @version $Id: redirect.php,v 1.72.2.13 2006/08/03 15:13:36 kink Exp $
  * @package squirrelmail
  */
 
@@ -146,11 +146,15 @@ $redirect_url = 'webmail.php';
 
 if ( sqgetGlobalVar('session_expired_location', $session_expired_location, SQ_SESSION) ) {
     sqsession_unregister('session_expired_location');
-    $compose_new_win = getPref($data_dir, $username, 'compose_new_win', 0);
-    if ($compose_new_win) {
-        $redirect_url = $session_expired_location;
-    } elseif ( strpos($session_expired_location, 'webmail.php') === FALSE ) {
-        $redirect_url = 'webmail.php?right_frame='.urldecode($session_expired_location);
+    if ( strpos($session_expired_location, 'compose.php') !== FALSE ) {
+        $compose_new_win = getPref($data_dir, $username, 'compose_new_win', 0);
+        if ($compose_new_win) {
+            $redirect_url = $session_expired_location;
+        } elseif ( strpos($session_expired_location, 'webmail.php') === FALSE ) {
+            $redirect_url = 'webmail.php?right_frame=compose.php';
+        }
+    } else {
+        $redirect_url = 'webmail.php?right_frame=' . urldecode($session_expired_location);
     }
     unset($session_expired_location);
 }
@@ -194,4 +198,4 @@ function attachment_common_parse($str, $debug) {
     sqsession_register($attachment_common_types, 'attachment_common_types');
 }
 
-?>
\ No newline at end of file
+?>
