@@ -3,13 +3,12 @@
 /**
  * right_main.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This is where the mailboxes are listed. This controls most of what
  * goes on in SquirrelMail.
  *
- * @version $Id: right_main.php,v 1.104.2.8 2004/12/27 15:04:00 kink Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: right_main.php,v 1.104.2.15 2006/06/02 02:52:15 jangliss Exp $
  * @package squirrelmail
  */
 
@@ -132,7 +131,7 @@ if ($imap_server_type == 'uw' && (strstr($mailbox, '../') ||
 }
 
 /* decide if we are thread sorting or not */
-if ($allow_thread_sort == TRUE) {
+if (!empty($allow_thread_sort) && ($allow_thread_sort == TRUE)) {
     if (isset($set_thread)) {
         if ($set_thread == 1) {
             setPref($data_dir, $username, "thread_$mailbox", 1);
@@ -151,8 +150,6 @@ else {
     $thread_sort_messages = 0;
 }
 
-do_hook ('generic_header');
-
 sqimap_mailbox_select($imapConnection, $mailbox);
 
 if ($composenew) {
@@ -165,7 +162,7 @@ if ($composenew) {
 
 do_hook('right_main_after_header');
 if (isset($note)) {
-    echo html_tag( 'div', '<b>' . $note .'</b>', 'center' ) . "<br />\n";
+    echo html_tag( 'div', '<b>' . htmlspecialchars($note) .'</b>', 'center' ) . "<br />\n";
 }
 
 if ( sqgetGlobalVar('just_logged_in', $just_logged_in, SQ_SESSION) ) {
@@ -222,9 +219,10 @@ if ($use_mailbox_cache && sqsession_is_registered('msgs')) {
 
     $numMessages = sqimap_get_num_messages ($imapConnection, $mailbox);
 
+    // set 8th argument to false in order to make sure that cache is not used.
     showMessagesForMailbox($imapConnection, $mailbox, $numMessages,
                            $startMessage, $sort, $color, $show_num,
-                           $use_mailbox_cache);
+                           false);
 
     if (sqsession_is_registered('msgs') && isset($msgs)) {
         sqsession_register($msgs, 'msgs');
@@ -241,4 +239,4 @@ sqimap_logout ($imapConnection);
 
 echo '</body></html>';
 
-?>
\ No newline at end of file
+?>
