@@ -3,12 +3,11 @@
 /**
  * vcard.php
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This file shows an attched vcard
  *
- * @version $Id: vcard.php,v 1.23.2.12 2006/02/03 22:27:55 jervfors Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: vcard.php,v 1.23.2.14 2006/04/14 22:27:08 jervfors Exp $
  * @package squirrelmail
  */
 
@@ -181,7 +180,7 @@ if (isset($vcard_nice['org'])) {
 if (isset($vcard_nice['title'])) {
     echo '<option value="' . htmlspecialchars($vcard_nice['title']) .
         '; ' . htmlspecialchars($vcard_nice['org']) .
-        '">' . _("Title & Org. / Dept.") . "</option>\n";
+        '">' . _("Title &amp; Org. / Dept.") . "</option>\n";
 }
 if (isset($vcard_nice['tel;work'])) {
     echo '<option value="' . htmlspecialchars($vcard_nice['tel;work']) .
