@@ -3,14 +3,13 @@
 /**
  * view_text.php -- Displays the main frameset
  *
- * Copyright (c) 1999-2005 The SquirrelMail development team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Who knows what this file does. However PUT IT HERE DID NOT PUT
  * A SINGLE FREAKING COMMENT IN! Whoever is responsible for this,
  * be very ashamed.
  *
- * @version $Id: view_text.php,v 1.17.2.4 2004/12/27 15:04:02 kink Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: view_text.php,v 1.17.2.9 2006/04/14 22:27:08 jervfors Exp $
  * @package squirrelmail
  */
 
@@ -51,7 +50,7 @@ $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0
 $mbx_response = sqimap_mailbox_select($imapConnection, $mailbox);
 
 $message = &$messages[$mbx_response['UIDVALIDITY']][$passed_id];
-$message_ent = &$message->getEntity($ent_id);
+$message_ent = $message->getEntity($ent_id);
 if ($passed_ent_id) {
     $message = &$message->getEntity($passed_ent_id);
 }
@@ -77,6 +76,9 @@ if (isset($languages[$squirrelmail_language]['XTRA_CODE']) &&
 
 if ($type1 == 'html' || (isset($override_type1) &&  $override_type1 == 'html')) {
     $body = MagicHTML( $body, $passed_id, $message, $mailbox);
+    // html attachment with character set information
+    if (! empty($charset))
+        $body = charset_decode($charset,$body,false,true);
 } else {
     translateText($body, $wrap_at, $charset);
 }
@@ -100,4 +102,4 @@ echo '<a href="' . $dwnld_url . '">' . _("Download this as a file") . '</a>';
 <tr><td bgcolor="<?php echo $color[4]; ?>"><tt>
 <?php echo $body; ?>
 </tt></td></tr></table>
-</body></html>
+</body></html>
\ No newline at end of file
