@@ -9,7 +9,7 @@
  *
  * @copyright &copy; 1999-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: webmail.php,v 1.92.2.18 2006/06/02 15:51:50 tokul Exp $
+ * @version $Id: webmail.php,v 1.92.2.19 2006/08/03 14:48:09 kink Exp $
  * @package squirrelmail
  */
 
@@ -52,10 +52,6 @@ if (!sqgetGlobalVar('mailbox', $mailbox)) {
     $mailbox = 'INBOX';
 }
 
-if ( isset($_SESSION['session_expired_post']) ) {
-    sqsession_unregister('session_expired_post');
-}
-
 if(!sqgetGlobalVar('mailto', $mailto)) {
     $mailto = '';
 }
@@ -180,4 +176,4 @@ if($ret != '') {
 echo $output;
 ?>
 </frameset>
-</html>
\ No newline at end of file
+</html>
